==> nteract-0.0.10.tgz: package/src/notebook/constants.js <==
export const CHANGE_FILENAME = 'CHANGE_FILENAME';

export const START_SAVING = 'START_SAVING';
export const DONE_SAVING = 'DONE_SAVING';

export const ERROR_KERNEL_NOT_CONNECTED = 'ERROR_KERNEL_NOT_CONNECTED';

export const ERROR_KERNEL_LAUNCH_FAILED = 'ERROR_KERNEL_LAUNCH_FAILED';
export const ERROR_EXECUTING = 'ERROR_EXECUTING';

export const LAUNCH_KERNEL = 'LAUNCH_KERNEL';
export const NEW_KERNEL = 'NEW_KERNEL';
export const KILL_KERNEL = 'KILL_KERNEL';
export const INTERRUPT_KERNEL = 'INTERRUPT_KERNEL';

export const EXIT = 'EXIT';

export const SET_NOTEBOOK = 'SET_NOTEBOOK';

export const MOVE_CELL = 'MOVE_CELL';
export const REMOVE_CELL = 'REMOVE_CELL';

export const NEW_NOTEBOOK = 'NEW_NOTEBOOK';
export const READ_NOTEBOOK = 'READ_NOTEBOOK';

export const NEW_CELL_AFTER = 'NEW_CELL_AFTER';
export const NEW_CELL_BEFORE = 'NEW_CELL_BEFORE';
export const NEW_CELL_APPEND = 'NEW_CELL_APPEND';

export const MERGE_CELL_AFTER = 'MERGE_CELL_AFTER';
export const SPLIT_CELL = 'SPLIT_CELL';

export const ABORT_EXECUTION = 'ABORT_EXECUTION';

export const UPDATE_CELL_EXECUTION_COUNT = 'UPDATE_CELL_EXECUTION_COUNT';
export const CLEAR_CELL_OUTPUT = 'CLEAR_CELL_OUTPUT';

export const CHANGE_OUTPUT_VISIBILITY = 'CHANGE_OUTPUT_VISIBILITY';
export const CHANGE_INPUT_VISIBILITY = 'CHANGE_INPUT_VISIBILITY';

export const UPDATE_CELL_OUTPUTS = 'UPDATE_CELL_OUTPUTS';
export const UPDATE_CELL_SOURCE = 'UPDATE_CELL_SOURCE';

export const UPDATE_CELL_PAGERS = 'UPDATE_CELL_PAGERS';

export const SET_LANGUAGE_INFO = 'SET_LANGUAGE_INFO';

export const SET_EXECUTION_STATE = 'SET_EXECUTION_STATE';
export const FOCUS_CELL = 'FOCUS_CELL';
export const FOCUS_NEXT_CELL = 'FOCUS_NEXT_CELL';
export const FOCUS_PREVIOUS_CELL = 'FOCUS_PREVIOUS_CELL';
export const TOGGLE_STICKY_CELL = 'TOGGLE_STICKY_CELL';

export const SET_KERNEL_INFO = 'SET_KERNEL_INFO';
export const OVERWRITE_METADATA_FIELD = 'OVERWRITE_METADATA_FIELD';

export const STARTED_UPLOADING = 'STARTED_UPLOADING';
export const DONE_UPLOADING = 'DONE_UPLOADING';

export const SET_NOTIFICATION_SYSTEM = 'SET_NOTIFICATION_SYSTEM';

export const UPDATE_CELL_STATUS = 'UPDATE_CELL_STATUS';

export const COPY_CELL = 'COPY_CELL';
export const CUT_CELL = 'CUT_CELL';
export const PASTE_CELL = 'PASTE_CELL';

export const CHANGE_CELL_TYPE = 'CHANGE_CELL_TYPE';

export const SET_MODIFIED = 'SET_MODIFIED';

export const SET_THEME = 'SET_THEME';

export const SET_GITHUB = 'SET_GITHUB';

==> nteract-0.0.13.tgz: package/src/notebook/constants.js <==
export const CHANGE_FILENAME = 'CHANGE_FILENAME';

export const START_SAVING = 'START_SAVING';
export const DONE_SAVING = 'DONE_SAVING';

export const ERROR_KERNEL_NOT_CONNECTED = 'ERROR_KERNEL_NOT_CONNECTED';

export const ERROR_KERNEL_LAUNCH_FAILED = 'ERROR_KERNEL_LAUNCH_FAILED';
export const ERROR_EXECUTING = 'ERROR_EXECUTING';

export const LAUNCH_KERNEL = 'LAUNCH_KERNEL';
export const NEW_KERNEL = 'NEW_KERNEL';
export const KILL_KERNEL = 'KILL_KERNEL';
export const INTERRUPT_KERNEL = 'INTERRUPT_KERNEL';

export const EXIT = 'EXIT';

export const SET_NOTEBOOK = 'SET_NOTEBOOK';

export const MOVE_CELL = 'MOVE_CELL';
export const REMOVE_CELL = 'REMOVE_CELL';

export const NEW_NOTEBOOK = 'NEW_NOTEBOOK';
export const READ_NOTEBOOK = 'READ_NOTEBOOK';

export const NEW_CELL_AFTER = 'NEW_CELL_AFTER';
export const NEW_CELL_BEFORE = 'NEW_CELL_BEFORE';
export const NEW_CELL_APPEND = 'NEW_CELL_APPEND';

export const MERGE_CELL_AFTER = 'MERGE_CELL_AFTER';
export const SPLIT_CELL = 'SPLIT_CELL';

export const ABORT_EXECUTION = 'ABORT_EXECUTION';

export const UPDATE_CELL_EXECUTION_COUNT = 'UPDATE_CELL_EXECUTION_COUNT';
export const CLEAR_CELL_OUTPUT = 'CLEAR_CELL_OUTPUT';

export const CHANGE_OUTPUT_VISIBILITY = 'CHANGE_OUTPUT_VISIBILITY';
export const CHANGE_INPUT_VISIBILITY = 'CHANGE_INPUT_VISIBILITY';

export const UPDATE_CELL_OUTPUTS = 'UPDATE_CELL_OUTPUTS';
export const UPDATE_CELL_SOURCE = 'UPDATE_CELL_SOURCE';

export const UPDATE_CELL_PAGERS = 'UPDATE_CELL_PAGERS';

export const SET_LANGUAGE_INFO = 'SET_LANGUAGE_INFO';

export const SET_EXECUTION_STATE = 'SET_EXECUTION_STATE';
export const FOCUS_CELL = 'FOCUS_CELL';
export const FOCUS_NEXT_CELL = 'FOCUS_NEXT_CELL';
export const FOCUS_PREVIOUS_CELL = 'FOCUS_PREVIOUS_CELL';
export const TOGGLE_STICKY_CELL = 'TOGGLE_STICKY_CELL';

export const SET_KERNEL_INFO = 'SET_KERNEL_INFO';
export const OVERWRITE_METADATA_FIELD = 'OVERWRITE_METADATA_FIELD';

export const STARTED_UPLOADING = 'STARTED_UPLOADING';
export const DONE_UPLOADING = 'DONE_UPLOADING';

export const SET_NOTIFICATION_SYSTEM = 'SET_NOTIFICATION_SYSTEM';

export const UPDATE_CELL_STATUS = 'UPDATE_CELL_STATUS';

export const COPY_CELL = 'COPY_CELL';
export const CUT_CELL = 'CUT_CELL';
export const PASTE_CELL = 'PASTE_CELL';

export const CHANGE_CELL_TYPE = 'CHANGE_CELL_TYPE';

export const SET_MODIFIED = 'SET_MODIFIED';

export const SET_THEME = 'SET_THEME';

export const REGISTER_COMM_TARGET = 'REGISTER_COMM_TARGET';
export const SET_GITHUB_TOKEN = 'SET_GITHUB_TOKEN';
export const SET_ANON_GITHUB = 'SET_ANON_GITHUB';
export const SET_USER_GITHUB = 'SET_USER_GITHUB';

export const COMM_OPEN = 'COMM_OPEN';
export const COMM_MESSAGE = 'COMM_MESSAGE';
export const COMM_ERROR = 'COMM_ERROR';
